<?php

namespace Ems\Logic\ProcessamentoSolicitacao;

use Ems\Util\Utils;
use Util\Repositories;
use Teknisa\Model\Gestaopessoas\Entities\{ GpeItemsolicitacao, GpeSolicitacao };

abstract class ProcessamentoSolicitacao {
    
    /* @var GpeSolicitacao $solicitacao */
    private $solicitacao;
    
    /* @var GpeItemsolicitacao[] $itens */
    private $itens;
    
    /* @var array $extraData */
    private $solicitacaoExtraRow;
    
    public abstract function efetivar();
    public abstract function rejeitar();
    
    public function __construct(GpeSolicitacao $solicitacao, ?array $solicitacaoExtraRow = []) {
        $this->setSolicitacao($solicitacao);
        $this->solicitacaoExtraRow = $solicitacaoExtraRow;
    }
    
    private function setSolicitacao(GpeSolicitacao $solicitacao): void {
        $this->solicitacao  = $solicitacao;
        $this->itens        = $this->findItensSolicitacao();
    }
    
    public function findItensSolicitacao(): ?array {
        $nrSolicitacao = !empty($this->solicitacao) ? $this->solicitacao->getNrsolicitacao() : null;
        $findItensSolicitacaoConfig = array('nrorg' => Utils::getParamters()->getNrorg(), 'nrsolicitacao' => $nrSolicitacao);
        return Utils::getEntityManager()->getRepository(Repositories::GPE_ITEMSOLICITACAO)->findBy($findItensSolicitacaoConfig);
    }
    
    public function getItens(): ?array {
        return $this->itens;
    }
    
    public function getSolicitacao(): ?GpeSolicitacao {
        return $this->solicitacao;
    }
    
    public function getExtraRow(): ?array {
        return $this->solicitacaoExtraRow;
    }
    
    public function getItensAssociativeArray(): array {
        $arrayItens = [];
        foreach ($this->itens as $item) {
            $arrayItens[$item->getDschaveitemsoli()] = $item->getDsvaloritemsoli();
        }
        return $arrayItens;
    }
}