<?php

namespace Ems\Repository;

use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;
use Util\Environment;

class OcupacaoRepository {
    /** @var Connection */
    protected $connection;

    public function __construct(
        EntityManager $entityManager,
        Environment $environment
    ) {
        $this->entityManager    = $entityManager;
        $this->connection       = $entityManager->getConnection();
        $this->environment      = $environment;
    }



    public function getMotivoOcupa($nrorg) {
        $sql = <<<SQL
    SELECT
        *
    FROM
       GPE_MOTIVOOCUPA
    WHERE
       (
          NRORG = :P_NRORG
          OR NRORG = 0
       )
    ORDER BY NMMOTIVOOCUPA
SQL;


        $query = $this->entityManager->getConnection()->prepare($sql);

        $query->execute(
            array(
                'P_NRORG'           => $nrorg
            )
        );

        $resultQuery = $query->fetchAll();


        if (isset($resultQuery)) {
            return $resultQuery;
        } else {
            return null;
        }
    }

    public function getOcupacao($nrorg, $dtmescompetenc = null) {
        $sql = <<<SQL
            SELECT
                OCUPH.NMOCUPACAOH,
                OCUPM.NROCUPACAOM,
                OCUPM.NRTIPOOCUPACAO
            FROM
                GPE_OCUPACAOM OCUPM
                JOIN
                GPE_OCUPACAOH OCUPH ON
                OCUPH.NROCUPACAOM = OCUPM.NROCUPACAOM AND
                OCUPH.NRORG = OCUPM.NRORG AND
                OCUPH.DTMESCOMPETENC = (
                    SELECT
                        MAX(DTMESCOMPETENC)
                    FROM
                        GPE_OCUPACAOH
                    WHERE
                        NRORG = OCUPH.NRORG AND
                        NROCUPACAOM = OCUPH.NROCUPACAOM
                )
            WHERE
                OCUPM.NRORG = :P_NRORG AND
                (
                    OCUPM.DTFIMVIGENCIA >= TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY') OR
                    OCUPM.DTFIMVIGENCIA IS NULL
                )
            ORDER BY OCUPH.NMOCUPACAOH
SQL;

        $query = $this->entityManager->getConnection()->prepare($sql);

        $dtmescompetenc = empty($dtmescompetenc) ? $this->environment->getDtmescomptencDiaCorrente() : $dtmescompetenc;

        $query->execute(
            array(
                'P_NRORG'           => $nrorg,
                'P_DTMESCOMPETENC'  => $dtmescompetenc
            )
        );

        $resultQuery = $query->fetchAll();


        if (isset($resultQuery)) {
            return $resultQuery;
        } else {
            return null;
        }
    }

    public function setAlteOcupacao(
        array $params
    ): void {
        $sql = <<<SQL
            INSERT INTO GPE_ALTEOCUPACAO (
                NRORG,          NRALTEOCUPACAO,     NRVINCULOM,
                DTINIOCUPACAO,  DTFIMOCUPACAO,      NROCUPACAOM,
                NRNIVELOCUPA,   NRMOTIVOOCUPA,      NRTPMODALIDSAL,
                DSOBSERVACAO,   DTINCLUSAO,         DTULTATU,
                NRORGINCLUSAO,  CDOPERINCLUSAO,     NRORGULTATU,
                CDOPERULTATU,   NRTIPOOCUPACAO,     NRFAIXA
            )
            VALUES (
                :NRORG,         :NRALTEOCUPACAO,    :NRVINCULOM,
                :DTINIOCUPACAO, :DTFIMOCUPACAO,     :NROCUPACAOM,
                :NRNIVELOCUPA,  :NRMOTIVOOCUPA,     :NRTPMODALIDSAL,
                :DSOBSERVACAO,  :DTINCLUSAO,        :DTULTATU,
                :NRORGINCLUSAO, :CDOPERINCLUSAO,    :NRORGULTATU,
                :CDOPERULTATU,  :NRTIPOOCUPACAO,    :NRFAIXA
            )
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
}
